::: beignet.add_chebyshev_polynomial
::: beignet.chebyshev_extrema
::: beignet.chebyshev_gauss_quadrature
::: beignet.chebyshev_interpolation
::: beignet.chebyshev_polynomial_companion
::: beignet.chebyshev_polynomial_domain
::: beignet.chebyshev_polynomial_from_roots
::: beignet.chebyshev_polynomial_one
::: beignet.chebyshev_polynomial_power
::: beignet.chebyshev_polynomial_roots
::: beignet.chebyshev_polynomial_to_polynomial
::: beignet.chebyshev_polynomial_vandermonde
::: beignet.chebyshev_polynomial_vandermonde_2d
::: beignet.chebyshev_polynomial_vandermonde_3d
::: beignet.chebyshev_polynomial_weight
::: beignet.chebyshev_polynomial_x
::: beignet.chebyshev_polynomial_zero
::: beignet.chebyshev_zeros
::: beignet.differentiate_chebyshev_polynomial
::: beignet.divide_chebyshev_polynomial
::: beignet.evaluate_chebyshev_polynomial
::: beignet.evaluate_chebyshev_polynomial_2d
::: beignet.evaluate_chebyshev_polynomial_3d
::: beignet.evaluate_chebyshev_polynomial_cartesian_2d
::: beignet.evaluate_chebyshev_polynomial_cartesian_3d
::: beignet.fit_chebyshev_polynomial
::: beignet.integrate_chebyshev_polynomial
::: beignet.linear_chebyshev_polynomial
::: beignet.multiply_chebyshev_polynomial
::: beignet.multiply_chebyshev_polynomial_by_x
::: beignet.subtract_chebyshev_polynomial
::: beignet.trim_chebyshev_polynomial_coefficients
